@@ -85,6 +85,15 @@ class Node:
         return f"""#!/bin/bash
 echo Working Directory
 pwd
+echo Worker Identification
+echo NOMAD_ALLOC_ID
+echo $NOMAD_ALLOC_ID
+echo NOMAD_GROUP_NAME
+echo $NOMAD_GROUP_NAME
+echo NOMAD_HOST_ADDR_worker
+echo $NOMAD_HOST_ADDR_worker
+echo NOMAD_ALLOC_NAME
+echo $NOMAD_ALLOC_NAME
 echo Host Python Environment i.e. system-site-packages
 pip list
 echo Creating Virtual Environment
