@@ -3,9 +3,6 @@ import json
 import string
 from os import environ
 from pathlib import Path
-from typing import List
-from typing import Optional
-from typing import Union
 
 from airflow import DAG
 
@@ -54,9 +51,9 @@ class Workflow:
         output_data: str,
         category: str,
         workflow_package: str,
-        detail: Optional[str] = None,
-        tags: Optional[List[str]] = None,
-        workflow_version: Optional[str] = None,
+        detail: str | None = None,
+        tags: list[str] | None = None,
+        workflow_version: str | None = None,
     ):
         """
         Create a workflow instance.
@@ -183,7 +180,7 @@ class Workflow:
         """Retrieve the native engine (airflow) workflow object."""
         return self._dag
 
-    def export(self, export_path: Optional[Union[str, Path]] = None) -> Path:
+    def export(self, export_path: str | Path | None = None) -> Path:
         """Write a file representation of the workflow which can be run independently of the task dependencies."""
         export_path = export_path or "export/"
         export_path = Path(export_path)
